==> frezka_admin_panel_updated_files_v3.0.0.zip: lang/es/booking.php <==
<?php

return [
   'title'=>'Reservaciones',
   'singular_title'=>'Reserva',
   'lbl_phone'=>'Teléfono:',
   'lbl_e-mail'=>'Correo electrónico:',
   'lbl_with'=>'Con',
   'lbl_at'=>'En:',
   'lbl_note'=>'Nota',
   'lbl_sub_tot'=>'Sub total:',
   'lbl_got_to_payment'=>'Ir al pago',
   'lbl_complete_now'=>'Complete ahora',
   'lbl_payment'=>'Pago',
   'lbl_pay_now'=>'Pagar ahora',
   'lbl_is_paid'=>'Pagado',
   'lbl_add_service'=>'Agregar servicio',
   'lbl_add_package' => 'Agregar Paquete',
   'lbl_date'=>'Fecha',
   'lbl_customer_name'=>'Nombre del cliente',
   'lbl_amount'=>'Cantidad',
   'lbl_duration'=>'Duración',
   'lbl_staff_name'=>'Nombre del personal',
   'lbl_services'=>'Servicios',
   'lbl_update_at'=>'Actualizado en',
   'lbl_status'=>'Estado',
   'booking_update'=>'Reserva actualizada',
   'booking_status_list'=>'Lista de estado de reserva',
   'search_booking'=>'Resultados de búsqueda para reservas.',
   'booking_detail'=>'Detalle de la reserva',
   'booking_list'=>'Lista de reservas',
   'status_update'=>'¡El estado ha sido actualizado!',
   'booking_delete'=>'Borrado exitosamente',
   'booking_not_found'=>'Reserva no encontrada',
   'payment_done'=>'Pago con éxito',
   'booking_branch'=>'Branch_list',
   'booking_timeslot'=>'Slot_time_list',
   'booking_category'=>'LISTA DE CATEGORÍA',
   'booking_sevice'=>'Servicios_list',
   'booking_employee'=>'LISTA DE EMPLEADOS',
   'booking_create'=>'Creado_booking',
   'booking_action_invalid'=>'Acción inválida',
   'booking_service_update'=>'Servicio de reserva actualizado con éxito',
   'payment_successfull'=>'Pago completado con éxito',
   'create_form'=>'La reserva se ha creado con éxito',
   'lbl_action'=>'Acción',
   'lbl_new_appointment'=>'Nueva cita',
   'lbl_appointment'=>'Cita',
   'lbl_advanced_filter'=>'Filtro avanzado',
   'lbl_booking_date'=>'Fecha para registrarse',
   'lbl_customer_name'=>'Nombre del cliente',
   'lbl_staff_name'=>'Nombre del personal',
   'lbl_services'=>'Servicios',
   'lbl_payment_status'=>'Estado de pago',
   'download_invoice'=>'Descargar factura',
   'name'=>'Nombre',
   'phone'=>'Teléfono',
   'email'=>'Correo electrónico',
   'payment_method'=>'Método de pago',
   'customer_info'=>'Información del cliente',
   'services'=>'Servicios',
   'unit_price'=>'Precio unitario',
   'qty'=>'Cantidad',
   'total_price'=>'Precio total',
   'tips'=>'Consejos',
   'tax'=>'IMPUESTO',
   'grand-total'=>'Gran total',
   'sub_total'=>'Subcontrol',
   'products'=>'Productos',
   'invoice_data'=>'Datos de facturación',
   'coupondiscount' => 'Descuento de cupón',
   'grand_total' => 'Total general',
   'tips' => 'Propinas',
   'billing_address' => 'Dirección de facturación'
     
];

==> frezka_admin_panel_updated_files_v3.3.0.zip: lang/es/booking.php <==
<?php

return [
   'title'=>'Reservaciones',
   'singular_title'=>'Reserva',
   'lbl_phone'=>'Teléfono:',
   'lbl_e-mail'=>'Correo electrónico:',
   'lbl_with'=>'Con',
   'lbl_at'=>'En:',
   'lbl_note'=>'Nota',
   'lbl_sub_tot'=>'Sub total:',
   'lbl_got_to_payment'=>'Ir al pago',
   'lbl_complete_now'=>'Complete ahora',
   'lbl_payment'=>'Pago',
   'lbl_pay_now'=>'Pagar ahora',
   'lbl_is_paid'=>'Pagado',
   'lbl_add_service'=>'Agregar servicio',
   'lbl_add_package' => 'Agregar Paquete',
   'lbl_date'=>'Fecha',
   'lbl_customer_name' => 'Cliente',
   'lbl_amount'=>'Cantidad',
   'lbl_duration'=>'Duración',
   'lbl_staff_name' => 'Personal',
   'lbl_services'=>'Servicios',
   'lbl_update_at'=>'Actualizado en',
   'lbl_status'=>'Estado',
   'booking_update'=>'Reserva actualizada',
   'booking_status_list'=>'Lista de estado de reserva',
   'search_booking'=>'Resultados de búsqueda para reservas.',
   'booking_detail'=>'Detalle de la reserva',
   'booking_list'=>'Lista de reservas',
   'status_update'=>'¡El estado ha sido actualizado!',
   'booking_delete'=>'Borrado exitosamente',
   'booking_not_found'=>'Reserva no encontrada',
   'payment_done'=>'Pago con éxito',
   'booking_branch'=>'Branch_list',
   'booking_timeslot'=>'Slot_time_list',
   'booking_category'=>'LISTA DE CATEGORÍA',
   'booking_sevice'=>'Servicios_list',
   'booking_employee'=>'LISTA DE EMPLEADOS',
   'booking_create'=>'Creado_booking',
   'booking_action_invalid'=>'Acción inválida',
   'booking_service_update'=>'Servicio de reserva actualizado con éxito',
   'payment_successfull'=>'Pago completado con éxito',
   'create_form'=>'La reserva se ha creado con éxito',
   'lbl_action'=>'Acción',
   'lbl_new_appointment'=>'Nueva cita',
   'lbl_appointment'=>'Cita',
   'lbl_advanced_filter'=>'Filtro avanzado',
   'lbl_booking_date'=>'Fecha para registrarse',
   'lbl_customer_name'=>'Nombre del cliente',
   'lbl_staff_name'=>'Nombre del personal',
   'lbl_services'=>'Servicios',
   'lbl_payment_status'=>'Estado de pago',
   'download_invoice'=>'factura',
   'name'=>'Nombre',
   'phone'=>'Teléfono',
   'email'=>'Correo electrónico',
   'payment_method'=>'Método de pago',
   'customer_info'=>'Información del cliente',
   'services'=>'Servicios',
   'unit_price'=>'Precio unitario',
   'qty'=>'Cantidad',
   'total_price'=>'Precio total',
   'tips'=>'Consejos',
   'tax'=>'IMPUESTO',
   'grand-total'=>'Gran total',
   'sub_total'=>'Subcontrol',
   'products'=>'Productos',
   'invoice_data'=>'Datos de facturación',
   'coupondiscount' => 'Descuento de cupón',
   'grand_total' => 'Total general',
   'tips' => 'Propinas',
   'billing_address' => 'Dirección de facturación',
   'grand_total' => 'Gran Total:',
   'lbl_packages' => 'Paquetes',
   'lbl_add_more' => 'Añadir Más',
   'lbl_packages_detail' => 'Detalles de Paquetes',
   'lbl_package_available' => 'Paquetes Disponibles',
   'lbl_package_active' => 'Tu paquete todavía está activo',
   'lbl_view_all' => 'Ver Todo',
   'booking_date' => 'Seleccionar Fecha de Reserva',
   'customer_name' => 'Seleccionar Nombre del Cliente',
   'staff_name' => 'Seleccionar Nombre del Personal',
   'select_service' => 'Seleccionar Servicios',
   'branch_name' => 'Nombre de la Sucursal',
   'invoice_time' => 'Hora de la Factura',
   'payment_type' => 'Tipo de pago',
    'service_amount' => 'Cantidad del servicio',
    'product_amount'=> 'Cantidad del producto',
    'package_amount' => 'Cantidad del paquete',
    'tip_amount' => 'Propina',
    'total' => 'Total',
    'final_total' => 'Total final',
    'booking_detail' => 'Detalles de la reserva',
    'booked_on' => 'Reservado en',
    'booked_by' => 'Reservado por',
    'updated_on' => 'Actualizado en',
    'updated_by' => 'Actualizado por',
    'sale' => 'Venta #0',
    'with' => 'Con',
    'sold_by' => 'Vendido por',
    'client_since' => 'Cliente desde',
    'coupon_discount' => 'Descuento por cupón',

];
